/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef UTILS_H_INCLUDED
#define UTILS_H_INCLUDED

#include <string>
#include <vector>

/** \brief Allocate enough memory and concatenate C strings
  * Sometimes we need to construct C strings to pass them
  * to various system APIs. This function makes it easy.
  * Don't forget to free the result (death of child process
  * in which this was called counts as freeing as well).
  *
  */
char* StrConcat(const char*a,const char*b);

/** \brief Return signum function
  * Returns -1 if value is negative, and 1 if value is positive.
  * Returns 0 if value is 0.
  */
inline int Signum(int x) { return x == 0 ? 0 : x < 0 ? -1 : 1; }
inline float Signum(float x) { return x == 0 ? 0 : x < 0 ? -1 : 1; }

/** \brief Return smaller of two values
  */
inline int Min(int x, int y) { return x < y ? x : y;  }
inline float Min(float x, float y) { return x < y ? x : y; }

/** \brief Explode by specified substring. Substring is removed.
  */
std::vector<std::string> StrExplode(const std::string& in, const std::string& delimiter);

#endif
